@@ -51,8 +51,13 @@ def regionprops_table(image : napari.types.ImageData, labels: napari.types.Label
     extra_properties = []
 
     if size:
-        properties = properties + ['area', 'bbox_area', 'convex_area', 'equivalent_diameter']
-
+        properties = properties + ['area', 'bbox_area', 'equivalent_diameter']
+        # Workaround to avoid existing scikit-image bug
+        # See https://github.com/scikit-image/scikit-image/issues/6432
+        if (len(labels.shape) == 3) and (_check_2D_labels_in_3D_images(labels)):
+            warnings.warn("2D labels are present in 3D label image, 'convex_area' not calculated")
+        else:
+            properties = properties + ['convex_area']
     if intensity:
         properties = properties + ['max_intensity', 'mean_intensity', 'min_intensity']
 
@@ -69,7 +74,13 @@ def regionprops_table(image : napari.types.ImageData, labels: napari.types.Label
             warnings.warn("Perimeter measurements are not supported in 3D")
 
     if shape:
-        properties = properties + ['solidity', 'extent', 'feret_diameter_max', 'local_centroid']
+        properties = properties + ['extent', 'local_centroid']
+        # Workaround to avoid existing scikit-image bug
+        # See https://github.com/scikit-image/scikit-image/issues/6432
+        if (len(labels.shape) == 3) and (_check_2D_labels_in_3D_images(labels)):
+            warnings.warn("2D labels are present in 3D label image, 'feret_diameter_max' and 'solidity' not calculated")
+        else:
+            properties = properties + ['solidity', 'feret_diameter_max']
         if len(labels.shape) == 2:
             properties = properties + ['major_axis_length', 'minor_axis_length', 'orientation', 'eccentricity']
             # we need these two to compute some shape descriptors
@@ -97,7 +108,7 @@ def regionprops_table(image : napari.types.ImageData, labels: napari.types.Label
     # weighted_moments_central
     # weighted_moments_hu
     # weighted_moments_normalized
-
+    print('PROPERTIES = ', properties)
     # quantitative analysis using scikit-image's regionprops
     from skimage.measure import regionprops_table as sk_regionprops_table
     table = sk_regionprops_table(np.asarray(labels).astype(int), intensity_image=np.asarray(image),
@@ -185,7 +196,18 @@ def ellipsoid_axis_lengths(table):
 regionprops_table_all_frames = analyze_all_frames(regionprops_table)
 register_function(regionprops_table_all_frames, menu="Measurement tables > Regionprops of all frames (nsr)")
 
+def _check_2D_labels_in_3D_images(label_image):
+    '''
+    Checks if there are 2D labels in a 3D label image
+    '''
+    from skimage.measure import regionprops as sk_regionprops
 
+    measurements = sk_regionprops(label_image)
+    for props in measurements:
+        label_shape = np.array(props.bbox[3:]) - np.array(props.bbox[:3])
+        if np.any(label_shape == 1):
+            return True
+    return False
 
 try:
     # morphometrics API
